@@ -21,7 +21,7 @@ has missing_after                  => 1800;
 has [qw(remove_after stuck_after)] => 172800;
 has tasks                          => sub { {} };
 
-our $VERSION = '10.24';
+our $VERSION = '10.25';
 
 sub add_task {
   my ($self, $name, $task) = @_;
@@ -938,6 +938,12 @@ Number of workers that are currently not processing a job.
 
 Uptime in seconds.
 
+=item workers
+
+  workers => 200;
+
+Number of registered workers.
+
 =back
 
 =head2 unlock
